[![GitHub Workflow Actions Status](https://github.com/mediapills/core/workflows/CI%20Build/badge.svg?branch=dev)](https://github.com/mediapills/core/actions)
[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://github.com/mediapills/core/blob/dev/LICENSE.md)
[![Requirements Status](https://requires.io/github/mediapills/core/requirements.svg?branch=dev)](https://requires.io/github/mediapills/core/requirements/?branch=dev)


# Install

These instructions will install package. This is a Python package that supports Python 3 on Linux, MacOS and Windows. We recommend using Python 3.6 or higher.

## Linux and Mac OS

To install package run:

```
python3 -m venv mediapills

source mediapills/bin/activate

pip install git+ssh://git@github.com/mediapills/core.git@dev#egg=mediapills.core
```

## Windows (CMD/PowerShell)

To install package on Windows (CMD/PowerShell)

To install package run:

```
python3 -m venv mediapills

./mediapills/bin/activate

pip install git+ssh://git@github.com/mediapills/core.git@dev#egg=mediapills.core
```
